.. currentmodule:: abjad.tools.mathtools

all_are_nonnegative_integer_equivalent_numbers
==============================================

.. autofunction:: all_are_nonnegative_integer_equivalent_numbers
